==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/errorsdialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "application.h"
#include "errorsdialog.h"
#include "configdefs/errorsconfigdefs.h"

#include <subtitle.h>
#include <subtitleline.h>
#include <subtitleiterator.h>

#include <qheader.h>
#include <qlayout.h>
#include <qpushbutton.h>
#include <qlabel.h>

#include <kapplication.h>
#include <kpopupmenu.h>
#include <kdebug.h>
#include <klocale.h>
#include <kstdaccel.h>
#include <kconfig.h>

using namespace SubtitleComposer;

ErrorsDialog::ErrorsDialog( QWidget* parent ):
	KDialogBase( parent, 0, false, i18n( "Subtitle Errors" ), 0 )
{
	QWidget* mainWidget = new QWidget( this );
	setMainWidget( mainWidget );

	QGridLayout* mainLayout = new QGridLayout( mainWidget );
	mainLayout->setAlignment( Qt::AlignTop );
	mainLayout->setSpacing( 5 );

	m_clearFixedButton = new QPushButton( mainWidget );
	m_clearFixedButton->setText( i18n( "Clear Fixed" ) );
	m_clearFixedButton->setEnabled( ! app()->errorsConfig()->optionAsBool( OPT_AUTO_CLEAR_FIXED ) );

	QPushButton* checkErrorsButton = new QPushButton( mainWidget );
	checkErrorsButton->setText( i18n( "Check Errors..." ) );

	QPushButton* clearErrorsButton = new QPushButton( mainWidget );
	clearErrorsButton->setText( i18n( "Clear Errors..." ) );

	QPushButton* settingsButton = new QPushButton( mainWidget );
	settingsButton->setText( i18n( "Settings..." ) );

	m_errorsWidget = new ErrorsWidget( mainWidget );

	m_statsLabel = new QLabel( mainWidget );

	mainLayout->addWidget( m_clearFixedButton, 0, 0 );
	mainLayout->addItem( new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum ), 0, 1 );
	mainLayout->addWidget( checkErrorsButton, 0, 2 );
	mainLayout->addWidget( clearErrorsButton, 0, 3 );
	mainLayout->addWidget( settingsButton, 0, 4 );
	mainLayout->addMultiCellWidget( m_errorsWidget, 1, 1, 0, 4 );
	mainLayout->addMultiCellWidget( m_statsLabel, 2, 2, 0, 4 );

	resize( 500, height() + 50 );

	onStatsChanged();

	connect( m_clearFixedButton, SIGNAL(clicked()), app(), SLOT(recheckAllErrors()) );
	connect( checkErrorsButton, SIGNAL(clicked()), app(), SLOT(checkErrors()) );
	connect( clearErrorsButton, SIGNAL(clicked()), app(), SLOT(clearErrors()) );
	connect( settingsButton, SIGNAL(clicked()), app(), SLOT(showErrorsConfig()) );

	connect( m_errorsWidget, SIGNAL(linesCountChanged(unsigned)), this, SLOT(onStatsChanged()) );
	connect( m_errorsWidget, SIGNAL(errorsCountChanged(unsigned)), this, SLOT(onStatsChanged()) );
	connect( m_errorsWidget, SIGNAL(marksCountChanged(unsigned)), this, SLOT(onStatsChanged()) );

	connect( app()->errorsConfig(), SIGNAL(optionChanged(const QString&, const QString&)),
			 this, SLOT(onOptionChanged(const QString&,const QString&)) );
}

ErrorsWidget* ErrorsDialog::errorsWidget()
{
	return m_errorsWidget;
}

void ErrorsDialog::onStatsChanged()
{
/*	m_statsLabel->setText(
		i18n( "1 line has errors and/or marks. ", "%n lines have errors and/or marks. ", m_errorsWidget->linesCount() ) +
		i18n( "1 error total. ", "%n errors total. ", m_errorsWidget->errorsCount() ) +
		i18n( "1 mark total.", "%n marks total.", m_errorsWidget->marksCount() )
	);*/

	m_statsLabel->setText(
		i18n( "%1 lines - %2 with errors - %3 with marks" )
			.arg( m_errorsWidget->linesCount() )
			.arg( m_errorsWidget->errorsCount() )
			.arg( m_errorsWidget->marksCount() )
	);
}

void ErrorsDialog::onOptionChanged( const QString& option, const QString& value )
{
	if ( option == OPT_AUTO_CLEAR_FIXED )
		m_clearFixedButton->setEnabled( value != "true" );
}

#include "errorsdialog.moc"

==> subtitlecomposer-0.4.2.tar.bz2: subtitlecomposer-0.4.2/src/main/errorsdialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "application.h"
#include "errorsdialog.h"
#include "configdefs/errorsconfigdefs.h"

#include <subtitle.h>
#include <subtitleline.h>
#include <subtitleiterator.h>

#include <qheader.h>
#include <qlayout.h>
#include <qpushbutton.h>
#include <qlabel.h>

#include <kapplication.h>
#include <kpopupmenu.h>
#include <kdebug.h>
#include <klocale.h>
#include <kstdaccel.h>
#include <kconfig.h>

using namespace SubtitleComposer;

ErrorsDialog::ErrorsDialog( QWidget* parent ):
	KDialogBase( parent, 0, false, i18n( "Subtitle Errors" ), 0 )
{
	QWidget* mainWidget = new QWidget( this );
	setMainWidget( mainWidget );

	QGridLayout* mainLayout = new QGridLayout( mainWidget );
	mainLayout->setAlignment( Qt::AlignTop );
	mainLayout->setSpacing( 5 );

	m_clearFixedButton = new QPushButton( mainWidget );
	m_clearFixedButton->setText( i18n( "Clear Fixed" ) );
	m_clearFixedButton->setEnabled( ! app()->errorsConfig()->optionAsBool( OPT_AUTO_CLEAR_FIXED ) );

	QPushButton* checkErrorsButton = new QPushButton( mainWidget );
	checkErrorsButton->setText( i18n( "Check Errors..." ) );

	QPushButton* clearErrorsButton = new QPushButton( mainWidget );
	clearErrorsButton->setText( i18n( "Clear Errors..." ) );

	QPushButton* settingsButton = new QPushButton( mainWidget );
	settingsButton->setText( i18n( "Settings..." ) );

	m_errorsWidget = new ErrorsWidget( mainWidget );

	m_statsLabel = new QLabel( mainWidget );

	mainLayout->addWidget( m_clearFixedButton, 0, 0 );
	mainLayout->addItem( new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum ), 0, 1 );
	mainLayout->addWidget( checkErrorsButton, 0, 2 );
	mainLayout->addWidget( clearErrorsButton, 0, 3 );
	mainLayout->addWidget( settingsButton, 0, 4 );
	mainLayout->addMultiCellWidget( m_errorsWidget, 1, 1, 0, 4 );
	mainLayout->addMultiCellWidget( m_statsLabel, 2, 2, 0, 4 );

	resize( 500, height() + 50 );

	onStatsChanged();

	connect( m_clearFixedButton, SIGNAL(clicked()), app(), SLOT(recheckAllErrors()) );
	connect( checkErrorsButton, SIGNAL(clicked()), app(), SLOT(checkErrors()) );
	connect( clearErrorsButton, SIGNAL(clicked()), app(), SLOT(clearErrors()) );
	connect( settingsButton, SIGNAL(clicked()), app(), SLOT(showErrorsConfig()) );

	connect( m_errorsWidget, SIGNAL(linesCountChanged(unsigned)), this, SLOT(onStatsChanged()) );
	connect( m_errorsWidget, SIGNAL(errorsCountChanged(unsigned)), this, SLOT(onStatsChanged()) );
	connect( m_errorsWidget, SIGNAL(marksCountChanged(unsigned)), this, SLOT(onStatsChanged()) );

	connect( app()->errorsConfig(), SIGNAL(optionChanged(const QString&, const QString&)),
			 this, SLOT(onOptionChanged(const QString&,const QString&)) );
}

ErrorsWidget* ErrorsDialog::errorsWidget()
{
	return m_errorsWidget;
}

void ErrorsDialog::onStatsChanged()
{
	QString lines = i18n( "Showing 1 line", "Showing %n lines", m_errorsWidget->linesCount() );
	if ( m_errorsWidget->linesCount() )
	{
		QString marks = i18n( "1 marked", "%n marked", m_errorsWidget->marksCount() );
		QString errors = i18n( "1 with errors", "%n with errors", m_errorsWidget->errorsCount() );
		m_statsLabel->setText( QString( "%1 (%2, %3)" ).arg( lines ).arg( marks ).arg( errors ) );
	}
	else
		m_statsLabel->setText( lines );
}

void ErrorsDialog::onOptionChanged( const QString& option, const QString& value )
{
	if ( option == OPT_AUTO_CLEAR_FIXED )
		m_clearFixedButton->setEnabled( value != "true" );
}

#include "errorsdialog.moc"
